@@ -8,7 +8,7 @@ class MongoUtil:
 
     def __init__(self, cache_dirname=None, MongoDB=None, replicaSet=None, db='test',
                  verbose=False, max_entries=float('inf'), username = None, 
-                 password = None, authSource = 'admin', readPreference='primary'):
+                 password = None, authSource = 'admin', readPreference='nearest'):
         self.client = pymongo.MongoClient(
             host=MongoDB, replicaSet=replicaSet, 
             username = username, password = password,
@@ -27,11 +27,11 @@ class MongoUtil:
             return (self.client, self.db_obj, collection)
         except pymongo.errors.ConnectionFailure:
             return ('Server not available')
-        except ServerSelectionTimeoutError:
+        except pymongo.errors.ServerSelectionTimeoutError:
             return ('Server timeout')
 
-    def print_schema(self, collection_str):
-        '''Print out schema of a collection
+    def get_schema(self, collection_str):
+        '''Get schema of a collection
            removed '_id' from collection due to its object type
            and universality 
         '''
